@@ -19,7 +19,6 @@ default_role = 'py:obj'
 sys.path.insert(0, os.path.abspath(os.path.join(os.getcwd(), '..')))
 
 exclude_trees = ['_build']
-default_role = 'obj'
 pygments_style = 'sphinx'
 html_theme = 'default'
 
@@ -28,7 +27,7 @@ html_style = 'rtd.css'
 html_static_path = ['_static']
 
 latex_documents = [
-  ('index', 'Invoke.tex', u'Invoke Documentation',
+  ('index', 'invoke.tex', u'Invoke Documentation',
    u'Jeff Forcier', 'manual'),
 ]
 
