@@ -13,8 +13,8 @@ class Executor(object):
         storing/retrieving state, e.g. how many times a given task has been run
         this session and so on.
 
-        The context is passed into any tasks that mark themselves as requiring
-        one for operation.
+        A copy of the context is passed into any tasks that mark themselves as
+        requiring one for operation.
         """
         self.collection = collection
         self.context = context
@@ -29,7 +29,8 @@ class Executor(object):
             namespaced tasks, e.g. ``subcollection.taskname``.
 
         :param kwargs:
-            A keyword argument dict expanded when calling the requested task. E.g.::
+            A keyword argument dict expanded when calling the requested task.
+            E.g.::
 
                 executor.execute('mytask', {'myarg': 'foo'})
 
@@ -68,7 +69,9 @@ class Executor(object):
         for t in tasks:
             args = []
             if t.contextualized:
-                args.append(self.context)
+                context = self.context.clone()
+                context.update(self.collection.configuration)
+                args.append(context)
             results[t] = t(*args, **kwargs)
         return results[task]
 
